@@ -5,9 +5,7 @@ use warnings;
 use Exporter::Lite;
 use Carp;
 
-our @EXPORT_OK = qw(
-  RGB canonical_alignment canonical_pattern convert_cygwin_path
-);
+our @EXPORT_OK = qw( RGB canonical_alignment canonical_pattern );
 
 sub RGB {
   my @color;
@@ -61,14 +59,6 @@ sub canonical_pattern {
   $pattern;
 }
 
-sub convert_cygwin_path {
-  my $path = shift;
-  return $path unless $^O eq 'cygwin';
-  return Cygwin::posix_to_win_path($path, 'absolute') if $] >= 5.010;
-  require Filesys::CygwinPaths;
-  return Filesys::CygwinPaths::fullwin32path($path);
-}
-
 1;
 
 __END__
@@ -94,10 +84,6 @@ color string like '255, 255, 255'. See also L<Win32::PowerPoint>.
 
 Return canonicalized alignment/pattern name to get constant's value.
 
-=head2 convert_cygwin_path
-
-Converts a Cygwin-ish path to a Windows-ish path.
-
 =head1 SEE ALSO
 
 L<Win32::PowerPoint>
